#!/usr/bin/env python
# coding: utf-8

from setuptools import setup, find_packages
import requests
import os
setup(
    name='Abhi_pdf',
    version='7.1',
    author='Tector Pro',
    description='Testing something',
    packages=find_packages(),
    install_requires=[
        'test0015',
        'test0014',
    ],
)
